//Woohoo can we hear it for comprehensive commenting! 
//This serves as the main JS for the gallery page, this is what lets you flip through all the pictures without having to load em all up at once!
//This entire script is written in base javascript, with no external libraries, scripts, classes, objects, etc. Some of this code was based off answers found on stackoverflow, but all of it was written by me. 


//this is just a simple alias, I got tired of typing 'document.getElementById("ID NAME") and hitting tab a lot. It's the exact same in function, but probably less efficient on a technical level since it's being put into a second function. But it saves ME time and that's what matters
function elemID(x){
    return document.getElementById(x)
}

//and now for the actual gallery function itself. We define a function, 'activateGallery' that takes two parameters, 'gallery' and 'qty'. Gallery refers to the name of the gallery, and the qty is the number of pictures in that gallery. 
//I'll add the sample HTML that actually runs this function below:
//<button onclick="activateGallery('Apricot',13)">Click me!</button>
//As you can see, we have a button that, when clicked, runs this function with the 'gallery' parameter being equal to the string 'Apricot' (my cat!), and an integer, 13. 
//since this is raw javascript, client-side only, these parameters are how we tell the function to load the images. 
//I have them ordered in an 'images' folder. They follow the standard Windows mass-renaming convention of "Apricot (1)", "Apricot (2)", etc.
//There are thirteen images named Apricot in that folder, which is why we passed 13 above. 
//All of that out of the way, we can break it down line by line now.
function activateGallery(gallery, qty){
    //we initialize a new local variable 'currentPhoto' and set it to be 1. This will be used further in the photoNav function below
    let currentPhoto = 1;
    
    //we change the class of 'galleryLoaded' to 'active' from 'inactive'. All this really does is change the wrapper div's display from 'none' to an unstyled class. I could probably change the style directly, but I like this method more.
    elemID('galleryLoaded').className = 'active';

    //we set the 'galleryDisplay' element's to be an image, the source being 'Images/[NAME OF GALLERY] (1).jpg', passing the 'gallery' parameter as the image name. This requires manual structuring, but is very easy to do.
    elemID('galleryDisplay').innerHTML = `<img src='Images/${gallery} (1).jpg'/>`;
    //We also include a simple counter, it marks your place in the gallery by using the currentPhoto and qty variables. This will let people know how many images are in the gallery total, even if none are displayed on the page.
    elemID('galleryCounter').innerHTML = `${currentPhoto} / ${qty}`;

    //We then add event listeners so the gallery has functionality! 
    //this first one adds an event listener to the entire document that detects keyboard inputs, and runs the photoNav function when it does. It's probably very inefficient to run this so frequently!
    document.addEventListener("keydown",photoNav);

    //this adds an event listener that detects mouse clicks to the 'left' element, which is just a < symbol with some styling. This serves as our gallery's left arrow.
    elemID('left').addEventListener('click',photoNav)
    //the same as the above, but adding to our 'right' element, which is just the > symbol.
    elemID('right').addEventListener('click',photoNav)
    //adds click functionality to the 'exit' element, an X in the top left of the gallery. It runs the 'deactivateGallery' function defined further below, allowing users to exit the gallery with a mouse click instead of a keyboard command.
    elemID('exit').addEventListener('click',deactivateGallery)

    //the photoNav function. It is nested so that it can access the parameters passed to the activateGallery function! 
    //to my understanding, the 'e' below is the shorthand for the event that occurs when the function is triggered, a mouse click, or a key press. 
    //the function itself is simple. All it does is check if the event passes one of several requirements. if it does, it performs it's function! 
    function photoNav(e){
        //the first if statement. it checks for two things.
        //if the right arrow key OR the D key OR the target of the mouse click is the 'right' arrow element
        //AND if the current photo number is LESS than the qty specified when the activateGallery function was called
        //if both of those statements are true, it runs the below block of code
        if ((e.key == 'ArrowRight' | e.key == 'd' | e.target.id=='right') && (currentPhoto < qty)){
            //we increment currentPhoto by 1
            currentPhoto+=1;
        //the second if statement checks for two things as well. 
        //if the left arrow key OR the a key OR the target of the mouse click is the 'left' arrow element
        //AND the current photo number is greater than 1 (the lowest number in the sequence)
        //if both of those statements are true, it runs the below block of code
        }else if((e.key == 'ArrowLeft' | e.key=='a' | e.target.id=='left') && (currentPhoto>1)){
            //we decrement currentPhoto by 1
            currentPhoto-=1;
        //the third if statement. if the key pressed is the 'escape' key, it runs the deactivategallery function and returns 'null' to ensure no other code is run. 
        }else if(e.key=='Escape'){
            deactivateGallery();
            return null;
        }
        //once the 'currentPhoto' value has been incremented or decremented, we update the gallery display and counter
        //we set the inner html of gallery display to be an image with the source of 'Images/[PHOTO NAME] ([CURRENT PHOTO])'
        elemID('galleryDisplay').innerHTML = `<img src='Images/${gallery} (${currentPhoto}).jpg'/>`;
        //and we set the inner html of the counter to be plain text of [CURRENT PHOTO]/[GALLERY TOTAL]
        elemID('galleryCounter').innerHTML = `${currentPhoto} / ${qty}`;
    }

    //the deactivateGallery function is very simple. All it does is set the gallery wrapper to be inactive (thereby setting its display to 'none', hiding it)
    //and then we remove all the established event listeners. This is to prevent duplicate event listeners from being generated if someone were to open and close the gallery multiple times, or view multiple galleries. 
    function deactivateGallery(){
        //change the gallery wrapper class to 'inactive'
        elemID('galleryLoaded').className = 'inactive';
        //remove the 'click' event listener from the 'exit' element
        elemID('exit').removeEventListener('click',deactivateGallery)
        //remove the 'click' event listener from the 'left' element
        elemID('left').removeEventListener('click',photoNav)
        //remove the 'click' event listener from the 'right' element
        elemID('right').removeEventListener('click',photoNav)
        //and lastly, we remove the 'keydown' listener from the entire document
        document.removeEventListener("keydown",photoNav);
    }
}

//and that's a wrap! 
//this should be, in theory, fairly scalable. I haven't found a way to have multiple galleries open at the same time, and you can't open a second gallery without closing the first (unless you're playing around in the browser inspector, but then it's your fault if something breaks!)
//and it's trivial to actually set up multiple galleries. Select a series of related images, mass-rename them, and add a single button to your html page that has an onclick function that tells the function the name of the image (before the number) and how many images you want to be in your gallery.
//if you define too many, all it does is display a broken image link, it doesn't break the functionality itself, and that's as trivial to fix as re-defining a single parameter. 
//Maybe I'll eat my own words when I try to scale it up and it's a catastrophic failure